@@ -1,3 +1,4 @@
+#%% begin initialize mediawiki-1.13.2-noname-P1
 ###################################################################
 export LANG=C
 export PATH=/bin:/usr/bin:/sbin:/usr/sbin
@@ -13,7 +14,7 @@ WWW=$ROOT/home/www
 if [ -f $ROOT/opt/htdocs/mediawiki ]; then
   /usr/bin/mv $ROOT/opt/htdocs/mediawiki $ROOT/opt/htdocs/mediawiki.bak
 fi
-(cd $ROOT/opt/htdocs; ln -sf mediawiki-1.11.2 mediawiki )
+(cd $ROOT/opt/htdocs; rm -f mediawiki; ln -sf mediawiki-1.13.2 mediawiki )
 
 
 FQDN=`hostname -f`
@@ -21,20 +22,17 @@ if [ ".$FQDN" = "." ]; then
   FQDN=localhost
 fi
 
-/bin/su - postgres -c "sh $ROOT/opt/htdocs/mediawiki/custom/create_mediawiki_db83"
-/usr/bin/cp $ROOT/opt/htdocs/mediawiki/custom/_htaccess $ROOT/opt/htdocs/mediawiki/.htaccess 
-/usr/bin/chown www.apache $ROOT/opt/htdocs/mediawiki/custom/.htaccess 
+/bin/su - postgres -c "sh $ROOT/opt/htdocs/mediawiki-1.13.2/custom/create_mediawiki-1.13_db83"
+/usr/bin/cp $ROOT/opt/htdocs/mediawiki-1.13.2/custom/_htaccess $ROOT/opt/htdocs/mediawiki-1.13.2/.htaccess 
 
 if [ ! -f $WWW/.postgresql/postgresql.crt ]; then
  /usr/bin/mkdir -p $WWW/.postgresql
  /usr/bin/cp $PG_DIR/data/server.crt $WWW/.postgresql/postgresql.crt
  /usr/bin/cp $PG_DIR/data/server.key $WWW/.postgresql/postgresql.key
- /usr/bin/chown -R www.apache  $WWW/.postgresql
+ /usr/bin/chown -R www:apache  $WWW/.postgresql
 fi
 
-#/usr/bin/chgrp -R apache $ROOT/opt/htdocs/mediawiki
-/usr/bin/chown www $ROOT/opt/htdocs/mediawiki-1.11.2/config
+/usr/bin/chown -R wadm:apache $ROOT/opt/htdocs/mediawiki-1.13.2
+/usr/bin/chown -R www $ROOT/opt/htdocs/mediawiki-1.13.2/config
 
-#if ! fgrep "mediawiki/cron.php" $ROOT/var/spool/cron/crontabs/www 1>/dev/null 2>&1; then
-#  echo "0  *  *  *  *	wget -O - -q http://$FQDN/mediawiki/cron.php" >> $ROOT/var/spool/cron/crontabs/www
-#fi
+#%% end
